==> scribus-1.2.tar.bz2: scribus-1.2/scribus/shadebutton.cpp <==
#include "shadebutton.h"
#include "shadebutton.moc"
#include "query.h"


ShadeButton::ShadeButton(QWidget* parent) : QToolButton(parent, "ShadeButton")
{
	char *tmp[] = {"0 %", "10 %", "20 %", "30 %", "40 %", "50 %", "60 %", "70 %", "80 %", "90 %", "100 %"};
	size_t array = sizeof(tmp) / sizeof(*tmp);
	FillSh = new QPopupMenu();
	FillSh->insertItem( tr("Other..."));
	for (uint a = 0; a < array; ++a)
		FillSh->insertItem(tmp[a]);
	setBackgroundMode(PaletteBackground);
	setPopup(FillSh);
	setPopupDelay(1);
	setText("100 %");
	FillSh->setItemChecked(FillSh->idAt(11), true);
	setAutoRaise(true);
	connect( FillSh, SIGNAL(activated(int)), this, SLOT(setShade(int)));
}

void ShadeButton::setShade(int id)
{
	bool ok = false;
	uint a;
	int c, b;
	for (a = 0; a < FillSh->count(); ++a)
		{
		FillSh->setItemChecked(FillSh->idAt(a), false);
		}
	c = FillSh->indexOf(id);
	FillSh->setItemChecked(id, true);
	if (c > 0)
		b = (c-1) * 10;
	if (c == 0)
		{
		Query* dia = new Query(this, "New", 1, 0, tr("&Shade:"), tr("Shade"));
		if (dia->exec())
    		{
			c = dia->Answer->text().toInt(&ok);
			if (ok)
				b = QMAX(QMIN(c, 100),0);
			else
				b = 100;
			delete dia;
			}
		else
			{
			delete dia;
			return;
			}
		}
	setText(QString::number(b)+" %");
	emit clicked();
}

int ShadeButton::getValue()
{
	int l = text().length();
	QString tx = text().remove(l-2,2);
	return tx.toInt();
}

void ShadeButton::setValue(int val)
{
	for (uint a = 0; a < FillSh->count(); ++a)
		{
		FillSh->setItemChecked(FillSh->idAt(a), false);
		}
	if ((val % 10) == 0)
		FillSh->setItemChecked(FillSh->idAt(val/10+1), true);
	else
		FillSh->setItemChecked(FillSh->idAt(0), true);
	setText(QString::number(val)+" %");
}

==> scribus-1.2.4.1.tar.bz2: scribus-1.2.4.1/scribus/shadebutton.cpp <==
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "shadebutton.h"
#include "shadebutton.moc"
#include "query.h"


ShadeButton::ShadeButton(QWidget* parent) : QToolButton(parent, "ShadeButton")
{
	QString tmp[] = {"0 %", "10 %", "20 %", "30 %", "40 %", "50 %", "60 %", "70 %", "80 %", "90 %", "100 %"};
	size_t array = sizeof(tmp) / sizeof(*tmp);
	FillSh = new QPopupMenu();
	FillSh->insertItem( tr("Other..."));
	for (uint a = 0; a < array; ++a)
		FillSh->insertItem(tmp[a]);
	setBackgroundMode(PaletteBackground);
	setPopup(FillSh);
	setPopupDelay(1);
	setText("100 %");
	FillSh->setItemChecked(FillSh->idAt(11), true);
	setAutoRaise(true);
	connect( FillSh, SIGNAL(activated(int)), this, SLOT(setShade(int)));
}

void ShadeButton::setShade(int id)
{
	bool ok = false;
	uint a;
	int c, b;
	for (a = 0; a < FillSh->count(); ++a)
		{
		FillSh->setItemChecked(FillSh->idAt(a), false);
		}
	c = FillSh->indexOf(id);
	FillSh->setItemChecked(id, true);
	if (c > 0)
		b = (c-1) * 10;
	if (c == 0)
		{
		Query* dia = new Query(this, "New", 1, 0, tr("&Shade:"), tr("Shade"));
		if (dia->exec())
    		{
			c = dia->Answer->text().toInt(&ok);
			if (ok)
				b = QMAX(QMIN(c, 100),0);
			else
				b = 100;
			delete dia;
			}
		else
			{
			delete dia;
			return;
			}
		}
	setText(QString::number(b)+" %");
	emit clicked();
}

int ShadeButton::getValue()
{
	int l = text().length();
	QString tx = text().remove(l-2,2);
	return tx.toInt();
}

void ShadeButton::setValue(int val)
{
	for (uint a = 0; a < FillSh->count(); ++a)
		{
		FillSh->setItemChecked(FillSh->idAt(a), false);
		}
	if ((val % 10) == 0)
		FillSh->setItemChecked(FillSh->idAt(val/10+1), true);
	else
		FillSh->setItemChecked(FillSh->idAt(0), true);
	setText(QString::number(val)+" %");
}
